@@ -33,8 +33,7 @@
 #define		LEFT_FREQ			(440.0 / SAMPLE_RATE) 
 #define		RIGHT_FREQ			(660.0 / SAMPLE_RATE) 
 
-int 
-main (void) 
+int main (void) 
 {	SNDFILE	*file ; 
 	SF_INFO	sfinfo ; 
 	int		k ; 
@@ -50,8 +49,8 @@ main (void)
 	sfinfo.samplerate  = SAMPLE_RATE ; 
 	sfinfo.samples     = SAMPLE_COUNT ; 
 	sfinfo.pcmbitwidth = 16 ; 
-	sfinfo.channels	   = 2 ; 
-	sfinfo.format      = (SF_FORMAT_WAV | SF_FORMAT_PCM) ; 
+	sfinfo.channels	   = 1; 
+	sfinfo.format      = (SF_FORMAT_WAV | SF_FORMAT_GSM610) ; 
 
 	if (! (file = sf_open_write ("sine.wav", &sfinfo))) 
 	{	printf ("Error : Not able to open output file.\n") ; 
@@ -64,7 +63,7 @@ main (void)
 		}
 	else if (sfinfo.channels == 2)
 	{	for (k = 0 ; k < SAMPLE_COUNT ; k++)	 
-		{	buffer [2*k  ] = 1000.0 * sin (LEFT_FREQ * 2 * k * M_PI) ; 
+		{	buffer [2*k  ] = AMPLITUDE * sin (LEFT_FREQ * 2 * k * M_PI) ; 
 			buffer [2*k+1] = AMPLITUDE * sin (RIGHT_FREQ * 2 * k * M_PI) ; 
 			} ; 
 		}
