@@ -330,7 +330,7 @@ aiff_open_read	(SF_PRIVATE *psf)
 			break ;
 			} ;
 
-		if (ftell (psf->file) >= (long) (psf->filelength - (2 * sizeof (dword))))
+		if (ftell (psf->file) >= (off_t) (psf->filelength - (2 * sizeof (dword))))
 			break ;
 		} ; /* while (1) */
 		
