@@ -83,7 +83,7 @@ static int paf24_write_i (SF_PRIVATE *psf, int *ptr, int len) ;
 static int paf24_write_f (SF_PRIVATE *psf, float *ptr, int len) ;
 static int paf24_write_d (SF_PRIVATE *psf, double *ptr, int len, int normalize) ;
 
-static long paf24_seek (SF_PRIVATE *psf, long offset, int whence) ;
+static off_t paf24_seek (SF_PRIVATE *psf, off_t offset, int whence) ;
 
 /*
 static void	endswap_paf_fmt (PAF_FMT *ppaf_fmt) ;
@@ -694,8 +694,8 @@ paf24_write_d (SF_PRIVATE *psf, double *ptr, int len, int normalize)
 /*---------------------------------------------------------------------------
 */
 
-static long 
-paf24_seek (SF_PRIVATE *psf, long offset, int whence)
+static off_t 
+paf24_seek (SF_PRIVATE *psf, off_t offset, int whence)
 {	PAF24_PRIVATE	*ppaf24 ; 
 	int				newblock, newsample ;
 	
@@ -706,14 +706,14 @@ paf24_seek (SF_PRIVATE *psf, long offset, int whence)
 
 	if (! (psf->blockwidth && psf->datalength && psf->dataoffset))
 	{	psf->error = SFE_BAD_SEEK ;
-		return	((long) -1) ;
+		return	((off_t) -1) ;
 		} ;
 		
 	switch (whence)
 	{	case SEEK_SET :
 				if (offset < 0 || offset > ppaf24->blocks * ppaf24->samplesperblock)
 				{	psf->error = SFE_BAD_SEEK ;
-					return	((long) -1) ;
+					return	((off_t) -1) ;
 					} ;
 				newblock  = offset / ppaf24->samplesperblock ;
 				newsample = offset % ppaf24->samplesperblock ;
@@ -722,7 +722,7 @@ paf24_seek (SF_PRIVATE *psf, long offset, int whence)
 		case SEEK_CUR :
 				if (psf->current + offset < 0 || psf->current + offset > ppaf24->blocks * ppaf24->samplesperblock)
 				{	psf->error = SFE_BAD_SEEK ;
-					return	((long) -1) ;
+					return	((off_t) -1) ;
 					} ;
 				newblock  = (psf->current + offset) / ppaf24->samplesperblock ;
 				newsample = (psf->current + offset) % ppaf24->samplesperblock ;
@@ -731,7 +731,7 @@ paf24_seek (SF_PRIVATE *psf, long offset, int whence)
 		case SEEK_END :
 				if (offset > 0 || ppaf24->samplesperblock * ppaf24->blocks + offset < 0)
 				{	psf->error = SFE_BAD_SEEK ;
-					return	((long) -1) ;
+					return	((off_t) -1) ;
 					} ;
 				newblock  = (ppaf24->samplesperblock * ppaf24->blocks + offset) / ppaf24->samplesperblock ;
 				newsample = (ppaf24->samplesperblock * ppaf24->blocks + offset) % ppaf24->samplesperblock ;
@@ -739,7 +739,7 @@ paf24_seek (SF_PRIVATE *psf, long offset, int whence)
 				
 		default : 
 				psf->error = SFE_BAD_SEEK ;
-				return	((long) -1) ;
+				return	((off_t) -1) ;
 		} ;
 		
 	if (psf->mode == SF_MODE_READ)
@@ -751,7 +751,7 @@ paf24_seek (SF_PRIVATE *psf, long offset, int whence)
 	else
 	{	/* What to do about write??? */ 
 		psf->error = SFE_BAD_SEEK ;
-		return	((long) -1) ;
+		return	((off_t) -1) ;
 		} ;
 
 	psf->current = newblock * ppaf24->samplesperblock + newsample ;
