@@ -298,8 +298,7 @@ sf_open_read	(const char *path, SF_INFO *sfinfo)
 		} ;
 
 	if (! validate_sfinfo (&(psf->sf)))
-	{	psf_log_SF_INFO (psf) ;
-		save_header_info (psf) ;
+	{	save_header_info (psf) ;
 		sf_errno = SFE_BAD_SF_INFO ;
 		sf_close (psf) ;
 		return NULL ;
@@ -577,8 +576,6 @@ sf_format_check	(const SF_INFO *info)
 					return 1 ;
 				if (subformat == SF_FORMAT_G723_24 && info->channels == 1)
 					return 1 ;
-				if (subformat == SF_FORMAT_FLOAT && (info->pcmbitwidth == 32))
-					return 1 ;
 				break ;
 				
 		case SF_FORMAT_RAW :
@@ -588,8 +585,9 @@ sf_format_check	(const SF_INFO *info)
 					return 1 ;
 				if (subformat != SF_FORMAT_PCM_BE && subformat != SF_FORMAT_PCM_LE)
 					break ;
-				if (! (info->pcmbitwidth % 8) && info->pcmbitwidth <= 32)
-					return 1 ;
+				if (info->pcmbitwidth % 8 || info->pcmbitwidth > 32)
+					break ;
+				return 1 ;
 				break ;
 
 		case SF_FORMAT_PAF :
@@ -597,8 +595,9 @@ sf_format_check	(const SF_INFO *info)
 					return 1 ;
 				if (subformat != SF_FORMAT_PCM_BE && subformat != SF_FORMAT_PCM_LE && subformat != SF_FORMAT_PCM)
 					break ;
-				if ((info->pcmbitwidth % 8) == 0 && info->pcmbitwidth <= 24)
-					return 1 ;
+				if (info->pcmbitwidth % 8 || info->pcmbitwidth > 24)
+					break ;
+				return 1 ;
 				break ;
 
 		case SF_FORMAT_SVX :
@@ -731,7 +730,7 @@ sf_command	(SNDFILE *sndfile, const char *cmd, void *data, int datasize)
 double  
 sf_signal_max   (SNDFILE *sndfile)
 {	SF_PRIVATE 		*psf ;
-	long			position ;
+	off_t			position ;
 	unsigned int	k, len, readcount ;
 	double 			max = 0.0, *data, temp ;
 	
@@ -782,16 +781,16 @@ sf_signal_max   (SNDFILE *sndfile)
 /*------------------------------------------------------------------------------
 */
 
-long	
-sf_seek	(SNDFILE *sndfile, long offset, int whence)
+off_t	
+sf_seek	(SNDFILE *sndfile, off_t offset, int whence)
 {	SF_PRIVATE 	*psf ;
-	long		realseek, position ;
+	off_t		realseek, position ;
 
 	VALIDATE_SNDFILE_AND_ASSIGN_PSF (sndfile, psf) ;
 	
 	if (! psf->sf.seekable)
 	{	psf->error = SFE_NOT_SEEKABLE ;
-		return	((long) -1) ;
+		return	((off_t) -1) ;
 		} ;
 	
 	if (psf->seek_func)
@@ -801,14 +800,14 @@ sf_seek	(SNDFILE *sndfile, long offset, int whence)
 		
 	if (! (psf->blockwidth && psf->datalength && psf->dataoffset))
 	{	psf->error = SFE_BAD_SEEK ;
-		return	((long) -1) ;
+		return	((off_t) -1) ;
 		} ;
 
 	switch (whence)
 	{	case SEEK_SET :
 				if (offset < 0 || offset * psf->blockwidth > psf->datalength)
 				{	psf->error = SFE_BAD_SEEK ;
-					return	((long) -1) ;
+					return	((off_t) -1) ;
 					} ;
 				realseek = psf->dataoffset + offset * psf->blockwidth ;
 				fseek (psf->file, realseek, SEEK_SET) ;
@@ -819,7 +818,7 @@ sf_seek	(SNDFILE *sndfile, long offset, int whence)
 				position = (ftell (psf->file) - psf->dataoffset) / psf->blockwidth ;
 				if (psf->current + offset > psf->sf.samples)
 				{	psf->error = SFE_BAD_SEEK ;
-					return	((long) -1) ;
+					return	((off_t) -1) ;
 					} ;
 				realseek = psf->dataoffset + (position + offset) * psf->blockwidth ;
 				fseek (psf->file, realseek, SEEK_SET) ;
@@ -829,7 +828,7 @@ sf_seek	(SNDFILE *sndfile, long offset, int whence)
 		case SEEK_END :
 				if (offset > 0 || psf->sf.samples + offset < 0)
 				{	psf->error = SFE_BAD_SEEK ;
-					return	((long) -1) ;
+					return	((off_t) -1) ;
 					} ;
 				realseek = (psf->sf.samples + offset) * psf->blockwidth + psf->dataoffset ;
 
@@ -839,7 +838,7 @@ sf_seek	(SNDFILE *sndfile, long offset, int whence)
 				
 		default : 
 				psf->error = SFE_BAD_SEEK ;
-				return	((long) -1) ;
+				return	((off_t) -1) ;
 		} ;
 
 	psf->current = (position - psf->dataoffset) / psf->blockwidth ;
