@@ -21,8 +21,6 @@
 #ifndef SNDFILE_H
 #define SNDFILE_H
 
-#define		SNDFILE_0
-
 #include	<stdio.h>
 #include	<stdlib.h>
 
@@ -34,7 +32,7 @@
 #include	<sys/types.h>
 #endif
 
-#if (defined (_WIN32))
+#ifdef _WIN32
 	#pragma pack(push,1)
 #endif
 
@@ -111,7 +109,7 @@ typedef	void	SNDFILE ;
 ** sf_open_write ().
 */
 
-struct SF_INFO
+typedef	struct
 {	unsigned int	samplerate ;
 	unsigned int	samples ;
 	unsigned int	channels ;
@@ -119,17 +117,15 @@ struct SF_INFO
 	unsigned int	format ;
 	unsigned int	sections ;
 	unsigned int	seekable ;
-} ;
-
-typedef	struct SF_INFO SF_INFO ;
+} SF_INFO ;
 
 /* Open the specified file for read or write. On error, this will return 
 ** a NULL pointer. To find the error number, pass a NULL SNDFILE to
 ** sf_perror () or sf_error_str ().
 */
 
-SNDFILE* 	sf_open_read	(const char *path, SF_INFO *sfinfo) ;
-SNDFILE* 	sf_open_write	(const char *path, const SF_INFO *sfinfo) ;
+SNDFILE* 	sf_open_read	(const char *path, SF_INFO *wfinfo) ;
+SNDFILE* 	sf_open_write	(const char *path, const SF_INFO *wfinfo) ;
 
 /* sf_perror () prints out the current error state.
 ** sf_error_str () returns the current error message to the caller in the 
@@ -170,7 +166,7 @@ double	sf_signal_max	(SNDFILE *sndfile) ;
 ** On error sf_seek returns -1.
 */
 
-long	sf_seek 		(SNDFILE *sndfile, long frames, int whence) ;
+off_t	sf_seek 		(SNDFILE *sndfile, off_t frames, int whence) ;
 
 /* Functions for reading/writing the waveform data of a sound file.
 */
