@@ -243,7 +243,7 @@ wav_open_read	(SF_PRIVATE *psf)
 					fseek (psf->file, psf->datalength, SEEK_CUR) ;
 
 					dword = ftell (psf->file) ;
-					if (dword != (long) (psf->dataoffset + psf->datalength))
+					if (dword != (off_t) (psf->dataoffset + psf->datalength))
 						psf_log_printf (psf, "*** fseek past end error ***\n", dword, psf->dataoffset + psf->datalength) ;
 					break ;
 
@@ -598,7 +598,6 @@ read_fmt_chunk (SF_PRIVATE *psf, WAV_FMT *wav_fmt)
 						&(wav_fmt->msadpcm.samplesperblock), &(wav_fmt->msadpcm.numcoeffs)) ;
 
 				bytespersec = (wav_fmt->min.samplerate * wav_fmt->min.blockalign) / wav_fmt->msadpcm.samplesperblock ;
-
 				if (wav_fmt->min.bytespersec == bytespersec)
 					psf_log_printf (psf, "  Bytes/sec     : %d\n", wav_fmt->min.bytespersec) ;
 				else if (wav_fmt->min.bytespersec == (wav_fmt->min.samplerate / wav_fmt->msadpcm.samplesperblock) * wav_fmt->min.blockalign) 
