@@ -64,7 +64,7 @@ static	int wav_gsm610_read (SF_PRIVATE *psf, GSM610_PRIVATE *pgsm610, short *ptr
 static	int	wav_gsm610_write_block (SF_PRIVATE *psf, GSM610_PRIVATE *pgsm610) ;
 static	int wav_gsm610_write (SF_PRIVATE *psf, GSM610_PRIVATE *pgsm610, short *ptr, int len) ;
 
-static long  wav_gsm610_seek   (SF_PRIVATE *psf, long offset, int whence) ;
+static off_t  wav_gsm610_seek   (SF_PRIVATE *psf, off_t offset, int whence) ;
 
 static int	wav_gsm610_read_s (SF_PRIVATE *psf, short *ptr, int len) ;
 static int	wav_gsm610_read_i (SF_PRIVATE *psf, int *ptr, int len) ;
@@ -327,8 +327,8 @@ wav_gsm610_read_d  (SF_PRIVATE *psf, double *ptr, int len, int normalize)
 	return total ;
 } /* wav_gsm610_read_d */
 
-static long    
-wav_gsm610_seek   (SF_PRIVATE *psf, long offset, int whence)
+static off_t    
+wav_gsm610_seek   (SF_PRIVATE *psf, off_t offset, int whence)
 {	GSM610_PRIVATE *pgsm610 ; 
 	int			newblock, newsample ;
 	
@@ -338,14 +338,14 @@ wav_gsm610_seek   (SF_PRIVATE *psf, long offset, int whence)
 
 	if (! (psf->blockwidth && psf->datalength && psf->dataoffset))
 	{	psf->error = SFE_BAD_SEEK ;
-		return	((long) -1) ;
+		return	((off_t) -1) ;
 		} ;
 		
 	switch (whence)
 	{	case SEEK_SET :
 				if (offset < 0 || offset > pgsm610->blocks * GSM610_SAMPLES)
 				{	psf->error = SFE_BAD_SEEK ;
-					return	((long) -1) ;
+					return	((off_t) -1) ;
 					} ;
 				newblock  = offset / GSM610_SAMPLES ;
 				newsample = offset % GSM610_SAMPLES ;
@@ -354,7 +354,7 @@ wav_gsm610_seek   (SF_PRIVATE *psf, long offset, int whence)
 		case SEEK_CUR :
 				if (psf->current + offset < 0 || psf->current + offset > pgsm610->blocks * GSM610_SAMPLES)
 				{	psf->error = SFE_BAD_SEEK ;
-					return	((long) -1) ;
+					return	((off_t) -1) ;
 					} ;
 				newblock  = (psf->current + offset) / GSM610_SAMPLES ;
 				newsample = (psf->current + offset) % GSM610_SAMPLES ;
@@ -363,7 +363,7 @@ wav_gsm610_seek   (SF_PRIVATE *psf, long offset, int whence)
 		case SEEK_END :
 				if (offset > 0 || GSM610_SAMPLES * pgsm610->blocks + offset < 0)
 				{	psf->error = SFE_BAD_SEEK ;
-					return	((long) -1) ;
+					return	((off_t) -1) ;
 					} ;
 				newblock  = (GSM610_SAMPLES * pgsm610->blocks + offset) / GSM610_SAMPLES ;
 				newsample = (GSM610_SAMPLES * pgsm610->blocks + offset) % GSM610_SAMPLES ;
@@ -371,7 +371,7 @@ wav_gsm610_seek   (SF_PRIVATE *psf, long offset, int whence)
 				
 		default : 
 				psf->error = SFE_BAD_SEEK ;
-				return	((long) -1) ;
+				return	((off_t) -1) ;
 		} ;
 		
 	if (psf->mode == SF_MODE_READ)
@@ -383,7 +383,7 @@ wav_gsm610_seek   (SF_PRIVATE *psf, long offset, int whence)
 	else
 	{	/* What to do about write??? */ 
 		psf->error = SFE_BAD_SEEK ;
-		return	((long) -1) ;
+		return	((off_t) -1) ;
 		} ;
 
 	psf->current = newblock * GSM610_SAMPLES + newsample ;
