@@ -29,7 +29,13 @@
 #include	"common.h"
 #include	"wav.h"
 
-/* These required here because we write the header in this file. */
+#if (CPU_IS_LITTLE_ENDIAN == 1)
+#	define	MAKE_MARKER(a,b,c,d)		((a)|((b)<<8)|((c)<<16)|((d)<<24))
+#elif (CPU_IS_BIG_ENDIAN == 1)
+#	define	MAKE_MARKER(a,b,c,d)		(((a)<<24)|((b)<<16)|((c)<<8)|(d))
+#else
+#	error "Cannot determine endian-ness of processor."
+#endif
 
 #define RIFF_MARKER	(MAKE_MARKER ('R', 'I', 'F', 'F')) 
 #define WAVE_MARKER	(MAKE_MARKER ('W', 'A', 'V', 'E')) 
@@ -97,10 +103,10 @@ static int AdaptCoeff2 [] =
 ** Static functions.
 */
 
-static	int	msadpcm_decode_block (SF_PRIVATE *psf, MSADPCM_PRIVATE *pms) ;
+static	int	msadpcm_read_block (SF_PRIVATE *psf, MSADPCM_PRIVATE *pms) ;
 static	int msadpcm_read (SF_PRIVATE *psf, MSADPCM_PRIVATE *pms, short *ptr, int len) ;
 
-static	int	msadpcm_encode_block (SF_PRIVATE *psf, MSADPCM_PRIVATE *pms) ;
+static	int	msadpcm_write_block (SF_PRIVATE *psf, MSADPCM_PRIVATE *pms) ;
 static	int msadpcm_write (SF_PRIVATE *psf, MSADPCM_PRIVATE *pms, short *ptr, int len) ;
 
 static	int	msadpcm_read_s (SF_PRIVATE *psf, short *ptr, int len) ;
@@ -113,12 +119,12 @@ static int	msadpcm_write_i  (SF_PRIVATE *psf, int *ptr, int len) ;
 static int	msadpcm_write_f  (SF_PRIVATE *psf, float *ptr, int len) ;
 static int	msadpcm_write_d  (SF_PRIVATE *psf, double *ptr, int len, int normalize) ;
 
-static long msadpcm_seek   (SF_PRIVATE *psf, long offset, int whence) ;
+static off_t msadpcm_seek   (SF_PRIVATE *psf, off_t offset, int whence) ;
 static	int	msadpcm_close	(SF_PRIVATE  *psf) ;
 
 static int	msadpcm_write_header (SF_PRIVATE  *psf) ;
 
-static	unsigned int srate2blocksize (unsigned int srate_chan_product) ;
+static	unsigned int srate2blocksize (unsigned int srate) ;
 static	void	choose_predictor (unsigned int channels, short *data, int *bpred, int *idelta) ;
 
 /*============================================================================================
@@ -160,7 +166,7 @@ wav_msadpcm_reader_init (SF_PRIVATE *psf, WAV_FMT *fmt)
 
 	psf_log_printf (psf, " bpred   idelta\n") ;
 
-	msadpcm_decode_block (psf, pms) ;
+	msadpcm_read_block (psf, pms) ;
 	
 	psf->read_short  = (func_short)  msadpcm_read_s ;
 	psf->read_int    = (func_int)    msadpcm_read_i ;
@@ -173,7 +179,7 @@ wav_msadpcm_reader_init (SF_PRIVATE *psf, WAV_FMT *fmt)
 } /* wav_msadpcm_reader_init */
 
 static int		
-msadpcm_decode_block (SF_PRIVATE *psf, MSADPCM_PRIVATE *pms)
+msadpcm_read_block (SF_PRIVATE *psf, MSADPCM_PRIVATE *pms)
 {	int		chan, k, blockindex, sampleindex ;
 	short	bytecode, bpred [2], chan_idelta [2] ;
 	
@@ -274,7 +280,7 @@ msadpcm_decode_block (SF_PRIVATE *psf, MSADPCM_PRIVATE *pms)
 		} ;
 
 	return 1 ;
-} /* msadpcm_decode_block */
+} /* msadpcm_read_block */
 
 static int 
 msadpcm_read (SF_PRIVATE *psf, MSADPCM_PRIVATE *pms, short *ptr, int len)
@@ -287,7 +293,7 @@ msadpcm_read (SF_PRIVATE *psf, MSADPCM_PRIVATE *pms, short *ptr, int len)
 			} ;
 		
 		if (pms->samplecount >= pms->samplesperblock)
-			msadpcm_decode_block (psf, pms) ;
+			msadpcm_read_block (psf, pms) ;
 		
 		count = (pms->samplesperblock - pms->samplecount) * pms->channels ;
 		count = (len - index > count) ? count : len - index ;
@@ -395,8 +401,8 @@ msadpcm_read_d  (SF_PRIVATE *psf, double *ptr, int len, int normalize)
 	return total ;
 } /* msadpcm_read_d */
 
-static long    
-msadpcm_seek   (SF_PRIVATE *psf, long offset, int whence)
+static off_t    
+msadpcm_seek   (SF_PRIVATE *psf, off_t offset, int whence)
 {	MSADPCM_PRIVATE *pms ; 
 	int			newblock, newsample ;
 	
@@ -406,14 +412,14 @@ msadpcm_seek   (SF_PRIVATE *psf, long offset, int whence)
 
 	if (! (psf->blockwidth && psf->datalength && psf->dataoffset))
 	{	psf->error = SFE_BAD_SEEK ;
-		return	((long) -1) ;
+		return	((off_t) -1) ;
 		} ;
 		
 	switch (whence)
 	{	case SEEK_SET :
 				if (offset < 0 || offset > pms->blocks * pms->samplesperblock)
 				{	psf->error = SFE_BAD_SEEK ;
-					return	((long) -1) ;
+					return	((off_t) -1) ;
 					} ;
 				newblock  = offset / pms->samplesperblock ;
 				newsample = offset % pms->samplesperblock ;
@@ -422,7 +428,7 @@ msadpcm_seek   (SF_PRIVATE *psf, long offset, int whence)
 		case SEEK_CUR :
 				if (psf->current + offset < 0 || psf->current + offset > pms->blocks * pms->samplesperblock)
 				{	psf->error = SFE_BAD_SEEK ;
-					return	((long) -1) ;
+					return	((off_t) -1) ;
 					} ;
 				newblock  = (psf->current + offset) / pms->samplesperblock ;
 				newsample = (psf->current + offset) % pms->samplesperblock ;
@@ -431,7 +437,7 @@ msadpcm_seek   (SF_PRIVATE *psf, long offset, int whence)
 		case SEEK_END :
 				if (offset > 0 || pms->samplesperblock * pms->blocks + offset < 0)
 				{	psf->error = SFE_BAD_SEEK ;
-					return	((long) -1) ;
+					return	((off_t) -1) ;
 					} ;
 				newblock  = (pms->samplesperblock * pms->blocks + offset) / pms->samplesperblock ;
 				newsample = (pms->samplesperblock * pms->blocks + offset) % pms->samplesperblock ;
@@ -439,19 +445,19 @@ msadpcm_seek   (SF_PRIVATE *psf, long offset, int whence)
 				
 		default : 
 				psf->error = SFE_BAD_SEEK ;
-				return	((long) -1) ;
+				return	((off_t) -1) ;
 		} ;
 		
 	if (psf->mode == SF_MODE_READ)
 	{	fseek (psf->file, (int) (psf->dataoffset + newblock * pms->blocksize), SEEK_SET) ;
 		pms->blockcount  = newblock ;
-		msadpcm_decode_block (psf, pms) ;
+		msadpcm_read_block (psf, pms) ;
 		pms->samplecount = newsample ;
 		}
 	else
 	{	/* What to do about write??? */ 
 		psf->error = SFE_BAD_SEEK ;
-		return	((long) -1) ;
+		return	((off_t) -1) ;
 		} ;
 
 	psf->current = newblock * pms->samplesperblock + newsample ;
@@ -467,7 +473,7 @@ wav_msadpcm_writer_init (SF_PRIVATE *psf)
 {	MSADPCM_PRIVATE	*pms ;
 	unsigned int 	pmssize, blockalign, samplesperblock ;
 	
-	blockalign      = srate2blocksize (psf->sf.samplerate * psf->sf.channels) ;	
+	blockalign      = srate2blocksize (psf->sf.samplerate) ;	
 	samplesperblock = 2 + 2 * (blockalign - 7 * psf->sf.channels) / psf->sf.channels ;
 	
 	pmssize = sizeof (MSADPCM_PRIVATE) + blockalign + 3 * psf->sf.channels * samplesperblock ;
@@ -504,7 +510,7 @@ wav_msadpcm_writer_init (SF_PRIVATE *psf)
 */
 
 static int		
-msadpcm_encode_block (SF_PRIVATE *psf, MSADPCM_PRIVATE *pms)
+msadpcm_write_block (SF_PRIVATE *psf, MSADPCM_PRIVATE *pms)
 {	unsigned int	blockindex ;
 	unsigned char	byte ;
 	int				chan, k, predict, bpred [2], idelta [2], errordelta, newsamp ;
@@ -556,6 +562,7 @@ msadpcm_encode_block (SF_PRIVATE *psf, MSADPCM_PRIVATE *pms)
 		}
 	else
 	{	/* Stereo file. */
+	
 		pms->block [0]	= bpred [0] ;	
 		pms->block [1]	= bpred [1] ;	
 
@@ -578,13 +585,10 @@ msadpcm_encode_block (SF_PRIVATE *psf, MSADPCM_PRIVATE *pms)
 		byte = 0 ;
 		chan = 1 ;
 		
-		for (k = 4 ; k < 2 * pms->samplesperblock ; k++)
-		{	chan = k & 1 ;
-
+		for (k = 4 ; k < pms->samplesperblock ; k+=2)
+		{	chan = chan ? 0 : 1 ;
 			predict = (pms->samples [k-2] * AdaptCoeff1 [bpred [chan]] + pms->samples [k-4] * AdaptCoeff2 [bpred [chan]]) >> 8 ;
 			errordelta = (pms->samples [k] - predict) / idelta [chan] ;
-
-
 			if (errordelta < -8)
 				errordelta = -8 ;
 			else if (errordelta > 7)
@@ -598,8 +602,7 @@ msadpcm_encode_block (SF_PRIVATE *psf, MSADPCM_PRIVATE *pms)
 				errordelta += 0x10 ;
 				
 			byte = (byte << 4) | (errordelta & 0xF) ;
-
-			if (chan)
+			if (k % 2)
 			{	pms->block [blockindex++] = byte ;
 				byte = 0 ;
 				} ;
@@ -607,7 +610,7 @@ msadpcm_encode_block (SF_PRIVATE *psf, MSADPCM_PRIVATE *pms)
 			idelta [chan] = (idelta [chan] * AdaptationTable [errordelta]) >> 8 ;
 			if (idelta [chan] < 16)
 				idelta [chan] = 16 ;
-			pms->samples [k] = newsamp ;
+			pms->samples [k-2] = newsamp ;
 			} ;
 		} ;
 
@@ -622,7 +625,7 @@ msadpcm_encode_block (SF_PRIVATE *psf, MSADPCM_PRIVATE *pms)
 	pms->samplecount = 0 ;
 			
 	return 1 ;
-} /* msadpcm_encode_block */
+} /* msadpcm_write_block */
 
 static int 
 msadpcm_write (SF_PRIVATE *psf, MSADPCM_PRIVATE *pms, short *ptr, int len)
@@ -640,7 +643,7 @@ msadpcm_write (SF_PRIVATE *psf, MSADPCM_PRIVATE *pms, short *ptr, int len)
 		total = index ;
 
 		if (pms->samplecount >= pms->samplesperblock)
-			msadpcm_encode_block (psf, pms) ;	
+			msadpcm_write_block (psf, pms) ;	
 		} ;
 
 	return total ;		
@@ -748,7 +751,7 @@ static int
 msadpcm_write_header (SF_PRIVATE  *psf)
 {	int  k, fmt_size, blockalign, samplesperblock, bytespersec, extrabytes ;
 
-	blockalign      = srate2blocksize (psf->sf.samplerate * psf->sf.channels) ;	
+	blockalign      = srate2blocksize (psf->sf.samplerate) ;	
 	samplesperblock = 2 + 2 * (blockalign - 7 * psf->sf.channels) / psf->sf.channels ;
 	bytespersec     = (psf->sf.samplerate * blockalign) / samplesperblock ;
 	
@@ -808,7 +811,7 @@ msadpcm_close	(SF_PRIVATE  *psf)
 		*/
 		 
 		if (pms->samplecount && pms->samplecount < pms->samplesperblock)
-			msadpcm_encode_block (psf, pms) ;	
+			msadpcm_write_block (psf, pms) ;	
 
 		fseek (psf->file, 0, SEEK_END) ;
 		psf->filelength = ftell (psf->file) ;
@@ -831,16 +834,16 @@ msadpcm_close	(SF_PRIVATE  *psf)
 */
 
 static	unsigned int 
-srate2blocksize (unsigned int srate_chan_product)
-{	if (srate_chan_product < 12000)
+srate2blocksize (unsigned int srate)
+{	if (srate < 12000)
 		return 256 ;
-	if (srate_chan_product < 23000)
+	if (srate < 23000)
 		return 512 ;
-	if (srate_chan_product < 44000)
-		return 1024 ;
-	return 2048 ;
+	return 1024 ;
 } /* srate2blocksize */
 
+
+
 /*----------------------------------------------------------------------------------------
 **	Choosing the block predictor.
 **	Each block requires a predictor and an idelta for each channel. 
