@@ -98,8 +98,6 @@ main (int argc, char *argv[])
 		pcm_test_short	("au", filename, SF_FORMAT_AU, SF_FORMAT_PCM) ;
 		pcm_test_24bit	("au", filename, SF_FORMAT_AU, SF_FORMAT_PCM, 0) ;
 		pcm_test_int	("au", filename, SF_FORMAT_AU, SF_FORMAT_PCM) ;
-
-		pcm_float_test	("au_float", filename, SF_FORMAT_AU, SF_FORMAT_FLOAT) ;
 		unlink (filename) ;
 		nTests++ ;
 		} ;
@@ -110,8 +108,6 @@ main (int argc, char *argv[])
 		pcm_test_short	("aule", filename, SF_FORMAT_AULE, SF_FORMAT_PCM) ;
 		pcm_test_24bit	("aule", filename, SF_FORMAT_AULE, SF_FORMAT_PCM, 0) ;
 		pcm_test_int	("aule", filename, SF_FORMAT_AULE, SF_FORMAT_PCM) ;
-
-		pcm_float_test	("aule_float", filename, SF_FORMAT_AULE, SF_FORMAT_FLOAT) ;
 		unlink (filename) ;
 		nTests++ ;
 		} ;
